#!/bin/sh -f
#*******************************************************************************
# "@(#) $Id: lms.sh,v 1.65 2012/05/08 "
#
# startet neue sh Shell, -f: unterdrueckt Expansion von Mustern in Dateispecs

# ------------- Part 1 set environments ------------------
# -z tested ob String leer ist

if [ -z "$SKYCAT_VER" ]; then
       SKYCAT_VER=2.7.3; export SKYCAT_VER
fi

S_V=$SKYCAT_VER

# default instrument option
# sets instrument number to l1 if not set on command line
# $1 ist das erste Argument, $2 das zweite usw.
# Syntax ${parameter:-word}: der parameter wird benutzt, sofern er gesetzt ist,
# wenn nicht, wird an seiner Stelle word benutzt
INSTRUMENT=${1:-l1}

# default command line options for skycat
CLO="-with_grid 1 -scrollbars 1 -rtd 0 -min_scale -8 -max_scale 8"
DB=true
DISPLAY=$DISPLAY

case $INSTRUMENT in
       l1 | L1 | Lucifer1 | LUCIFER1 )
       INSTR=LUCIFER1; if $DB; then echo " INSTR            = LUCIFER1"; fi;;
       l2 | L2 | Lucifer2 | LUCIFER2 )
       INSTR=LUCIFER2; if $DB; then echo " INSTR            = LUCIFER2"; fi;;
       * )
       echo "Exit : there is no $1 available; try l1 or l2"
       exit;;
esac

export INSTR

LMSROOT=${LMSROOT:-$HOME/lms_v165};         export LMSROOT;  # where lms is installed
ISF_DIR=$LMSROOT/lib/mos;                  export ISF_DIR;  # LUCIFER1/2.isf, MODS1/2.isf
INS_ROOT=$HOME;                            export INS_ROOT; # user home directory 
INS_USER=.lms;                             export INS_USER; # fims output dir
PREP_DIR=$INS_ROOT/$INS_USER/PREP;         export PREP_DIR; # where is the fits file
LOG_DIR=$INS_ROOT/$INS_USER/LOG;           export LOG_DIR;  # keep this 
SET_DIR=$INS_ROOT/$INS_USER/SET;           export SET_DIR;  # keep this 

# copy the MOS longslit masks to the SET directory 
# echo "copy MOS longslit masks to $SET_DIR"


# -------------------- PART 2 -- check settings -----------------


if [ -d $INS_ROOT ]
   then
   if $DB; then echo " INS_ROOT            = $INS_ROOT"; fi
   else echo "ERROR: $INS_ROOT does not exist"
        exit
fi


if [ -d $LMSROOT ]
   then
   if $DB; then echo " LMSROOT            = $LMSROOT"; fi
   else echo "ERROR: >$LMSROOT< does not exist"
        echo ">>>>>hint:"
        echo "setenv LMSROOT <..>/work (your LMS installation directory)"
        echo "LMSROOT=<..>/work; export LMSROOT (for bash)"
        echo "setenv LMSROOT ${PWD}/.."
        exit
fi


if [ -d $INS_ROOT/$INS_USER ]
   then
   if $DB; then echo " INS_ROOT/INS_USER   = $INS_ROOT/$INS_USER"; fi
   else echo "ERROR: >$INS_ROOT/$INS_USER< does not exist"
        mkdir $INS_ROOT/$INS_USER
        echo "created ----- $INS_ROOT/$INS_USER"
fi

# where to write the target setup files
# -------------------------------------
if [ -d $SET_DIR ]
   then 
   if $DB; then echo " SET_DIR             = $SET_DIR"; fi
   else echo "ERROR: >$SET_DIR< does not exist"
        mkdir $SET_DIR
        echo "created ----- $SET_DIR"
fi

# where to write the LMS log files
# -------------------------------------
if [ -d $LOG_DIR ]
   then
   if $DB; then echo " LOG_DIR             = $LOG_DIR"; fi
   else echo "ERROR: >$LOG_DIR< does not exist"
        mkdir $LOG_DIR
        echo "created ----- $LOG_DIR"
fi

# from where to load the fits files
# -------------------------------------
if [ -d $PREP_DIR ]
   then
   if $DB; then echo " PREP_DIR            = $PREP_DIR"; fi
   else echo "ERROR: >$PREP_DIR< does not exist"
        mkdir $PREP_DIR
        echo "created ----- $PREP_DIR"
fi


if [ -d $ISF_DIR ]
   then
   if $DB; then echo " ISF_DIR             = $ISF_DIR"; fi
   else echo "ERROR: >$ISF_DIR< does not exist"
        exit
fi


if [ -f $ISF_DIR/$INSTR.isf ]
   then
   if $DB; then echo " $INSTR.isf from       $ISF_DIR/$INSTR.isf"; fi
   else echo "ERROR: >$INSTR.isf< does not exist"
        exit
fi

#-------------- P L U G I N S -------------------------------
ESO_PLUG=$LMSROOT/lib/libesoPlugins.tcl
LMS_PLUG=$LMSROOT/lib/liblmsPlugins.tcl

SKYSEARCH_PLUGIN=$LMS_PLUG/SkySearch_plugin.tcl;       export SKYSEARCH_PLUGIN
SKYCAT_PLUG01=$LMS_PLUG/SkyCat_plugin.tcl
SKYCAT_PLUG02=$ESO_PLUG/PE_SkyCat_plugin.tcl

if $DB
   then
   echo
   echo " SKYSEARCH_PLUGIN    = $SKYSEARCH_PLUGIN"
   echo " SKYCAT_PLUG01       = $SKYCAT_PLUG01"
   echo " SKYCAT_PLUG02       = $SKYCAT_PLUG02"
   echo
   echo " test if file exists"
   echo
   if [ -f $SKYSEARCH_PLUGIN ]; then echo " found: $SKYSEARCH_PLUGIN"; else echo " where? $SKYSEARCH_PLUGIN"; fi
   if [ -f $SKYCAT_PLUG01 ];    then echo " found: $SKYCAT_PLUG01";    else echo " where? $SKYCAT_PLUG01"; fi
   if [ -f $SKYCAT_PLUG02 ];    then echo " found: $SKYCAT_PLUG02";    else echo " where? $SKYCAT_PLUG02"; fi
   echo
fi

# join all plugins to one single keyword
SKYCAT_PLUGIN=$SKYCAT_PLUG02:$SKYCAT_PLUG01; export SKYCAT_PLUGIN

if $DB; then echo " SKYCAT_PLUGIN       = >$SKYCAT_PLUGIN<"; fi


# ----------------------------
# print current version number 
# ----------------------------
echo
echo
echo
echo "     W E L C O M E     T O     L M S"
echo "   -----------------------------------"
echo 
echo " +----------------+                +------------------+"
# dieser Ausdruck funktioniert nur, wenn lms.sh,v definiert ist (Zeile 3)!!!!!!!!!!!!!!!!!!!!!!!
awk ' $4 ~ /lms.sh,v/ { printf(" |  LMS  %8s |----plugin----> | SkyCatTool ", $5) }' $LMSROOT/bin/lms.sh
echo $S_V" |"
echo " +----------------+                +------------------+"

echo
echo   " +------------------------------------------+"
echo   " | INPUT : "$PREP_DIR""
echo   " | OUTPUT: "$SET_DIR""
echo   " | LOGS  : "$LOG_DIR""
echo   " | LMS requires: SkyCat "$S_V""
echo   " +------------------------------------------+"
echo


# ------------------ PART 3 --- start skycat ------------------
echo

echo "skycat $CLO"

# call skycat

$LMSROOT/bin/skycat $CLO
# skycat  $CLO
#
# ___oOo___
